@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 =encoding utf-8
 
@@ -85,6 +85,8 @@ C<--xlate-engine=deepl>.
 
 =item B<--xlate-labor>
 
+=item B<--xlabor>
+
 Insted of calling translation engine, you are expected to work for.
 After preparing text to be translated, they are copied to the
 clipboard.  You are expected to paste them to the form, copy the
@@ -141,6 +143,13 @@ text is printed.
 
 =back
 
+=item B<--xlate-maxlen>=I<chars> (Default: 0)
+
+Specify the maximum length of text to be sent to the API at once.
+Default value is set as for free account service: 128K for the API
+(B<--xlate>) and 5000 for the clipboard interface (B<--xlate-labor>).
+You may be able to change these value if you are using Pro service.
+
 =item B<-->[B<no->]B<xlate-progress> (Default: True)
 
 See the tranlsation result in real time in the STDERR output.
@@ -268,7 +277,7 @@ use App::cdif::Command;
 use Hash::Util qw(lock_keys);
 use Unicode::EastAsianWidth;
 
-my %opt = (
+our %opt = (
     engine   => \(our $xlate_engine),
     progress => \(our $show_progress = 1),
     format   => \(our $output_format = 'conflict'),
@@ -280,6 +289,7 @@ my %opt = (
     auth_key => \(our $auth_key),
     method   => \(our $cache_method //= $ENV{GREPLE_XLATE_CACHE} || 'auto'),
     dryrun   => \(our $dryrun = 0),
+    maxlen   => \(our $max_length = 0),
     );
 lock_keys %opt;
 sub opt :lvalue { ${$opt{+shift}} }
@@ -500,6 +510,7 @@ builtin xlate-to=s         $lang_to
 builtin xlate-cache:s      $cache_method
 builtin xlate-engine=s     $xlate_engine
 builtin xlate-dryrun       $dryrun
+builtin xlate-maxlen=i     $max_length
 
 builtin deepl-auth-key=s   $App::Greple::xlate::deepl::auth_key
 builtin deepl-method=s     $App::Greple::xlate::deepl::method
